@@ -25,7 +25,7 @@ Clazz.prepareFields (c$, function(){
 this.moData =  new java.util.Hashtable();
 this.orbitals =  new JU.Lst();
 this.orbitalMaps =  new java.util.Hashtable();
-this.highLEnabled =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/J.quantum.QS.idSpherical.length, 0);
+this.highLEnabled =  Clazz.newIntArray (J.quantum.QS.idSpherical.length, 0);
 });
 Clazz.defineMethod(c$, "filterMO", 
 function(){
@@ -140,4 +140,4 @@ return (ea < eb ? -1 : ea > eb ? 1 : 0);
 /*eoif4*/})();
 };
 });
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Tue Jun 10 01:13:43 CEST 2025
