@@ -134,7 +134,7 @@ ac++;
 if (this.rd() != null && this.line.startsWith("$end")) break;
 continue;
 }shellCount++;
-var slater =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/4, 0);
+var slater =  Clazz.newIntArray (4, 0);
 tokens = this.getTokens();
 slater[0] = ac;
 slater[1] = J.adapter.readers.quantum.BasisFunctionReader.getQuantumShellTagID(tokens[0]);
@@ -150,7 +150,7 @@ gdata.addLast(JU.PT.getTokens(this.rd()));
 this.gaussians = JU.AU.newFloat2(gaussianCount);
 for (var i = 0; i < gaussianCount; i++) {
 tokens = gdata.get(i);
-this.gaussians[i] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.QualifiedName*/tokens.length, 0);
+this.gaussians[i] =  Clazz.newFloatArray (tokens.length, 0);
 for (var j = 0; j < tokens.length; j++) this.gaussians[i][j] = this.parseFloatStr(tokens[j]);
 
 }
@@ -229,7 +229,7 @@ Clazz.defineMethod(c$, "readMOs",
 function(restricted, moInfos){
 var mos = JU.AU.createArrayOfHashtable(6);
 var mocoef = JU.AU.newFloat2(6);
-var moid =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/6, 0);
+var moid =  Clazz.newIntArray (6, 0);
 var tokens;
 var energy;
 var nMOs = 0;
@@ -239,7 +239,7 @@ var nMO = tokens.length;
 energy = JU.PT.getTokens(this.rd().substring(13));
 for (var i = 0; i < nMO; i++) {
 moid[i] = this.parseIntStr(tokens[i]) - 1;
-mocoef[i] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nBasis, 0);
+mocoef[i] =  Clazz.newFloatArray (this.nBasis, 0);
 mos[i] =  new java.util.Hashtable();
 }
 for (var i = 0, pt = 0; i < this.nBasis; i++) {
@@ -313,4 +313,4 @@ c$.$DS_LIST = "D3    D4    D2    D5    D1";
 c$.$FC_LIST = "XXX   YYY   ZZZ   XYY   XXY   XXZ   XZZ   YZZ   YYZ   XYZ";
 c$.$FS_LIST = "F4    F5    F3    F6    F2    F7    F1";
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue Jun 10 01:13:43 CEST 2025
