@@ -33,7 +33,7 @@ this.bondOrder = this.parseBondToken(this.atts.get("order"));
 return;
 }if ("transformmat".equals(localName)) {
 this.elementContext = 4;
-this.trans =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
+this.trans =  Clazz.newFloatArray (16, 0);
 return;
 }}, "~S,~S");
 Clazz.defineMethod(c$, "parseBondToken", 
@@ -115,4 +115,4 @@ return;
 }}, "~S");
 c$.keepCharsList =  Clazz.newArray(-1, ["name", "x", "y", "z", "formalchg", "atomkey", "atsym", "e00", "e01", "e02", "e03", "e10", "e11", "e12", "e13", "e20", "e21", "e22", "e23", "e30", "e31", "e32", "e33"]);
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue Jun 10 01:13:43 CEST 2025
