@@ -603,4 +603,4 @@ bs.andNot(this.deleteAtoms);
 }});
 c$.unitCellParamTags =  Clazz.newArray(-1, ["a", "b", "c", "alpha", "beta", "gamma"]);
 });
-;//5.0.1-v4 Sat Dec 21 16:04:04 CST 2024
+;//5.0.1-v7 Tue Jun 10 01:13:43 CEST 2025
