@@ -233,4 +233,4 @@ this.asc.xtalSymmetry.setPartProperty();
 });
 c$.supportedRecordTypes =  Clazz.newArray(-1, ["TITL", "CELL", "SPGR", "SFAC", "LATT", "SYMM", "NOTE", "ATOM", "PART", "END"]);
 });
-;//5.0.1-v7 Thu Apr 24 21:16:01 CDT 2025
+;//5.0.1-v7 Wed Jun 11 09:30:30 CDT 2025
