@@ -580,10 +580,14 @@ Clazz.defineMethod(c$, "setSymmetryOperator",
 function(xyz){
 if (this.ignoreFileSymmetryOperators) return -1;
 var isym = this.asc.getXSymmetry().addSpaceGroupOperation(xyz, true);
-if (isym < 0) JU.Logger.warn("Skipping symmetry operation " + xyz);
+if (isym < 0) this.warnSkippingOperation(xyz);
 this.iHaveSymmetryOperators = true;
 return isym;
 }, "~S");
+Clazz.defineMethod(c$, "warnSkippingOperation", 
+function(xyz){
+JU.Logger.warn("Skipping symmetry operation " + xyz);
+}, "~S");
 Clazz.defineMethod(c$, "initializeCartesianToFractional", 
 function(){
 for (var i = 0; i < 16; i++) if (!Float.isNaN(this.unitCellParams[6 + i])) return;
@@ -936,7 +940,7 @@ sym = this.asc.getXSymmetry().applySymmetryFromReader(sym);
 this.asc.setTensors();
 }if (this.isTrajectory) this.asc.setTrajectory();
 if (this.moreUnitCellInfo != null) {
-this.asc.setCurrentModelInfo("moreUnitCellInfo", this.moreUnitCellInfo);
+this.setMoreInfo();
 this.moreUnitCellInfo = null;
 }this.finalizeSubclassSymmetry(sym != null);
 if (this.merging && sym != null && this.iHaveFractionalCoordinates && this.iHaveUnitCell && this.iHaveSymmetryOperators) {
@@ -945,12 +949,20 @@ this.addJmolScript("modelkit spacegroup P1");
 }this.initializeSymmetry();
 return sym;
 });
+Clazz.defineMethod(c$, "setMoreInfo", 
+function(){
+this.asc.setCurrentModelInfo("moreUnitCellInfo", this.moreUnitCellInfo);
+for (var i = this.moreUnitCellInfo.size(); --i >= 0; ) {
+var s = this.moreUnitCellInfo.get(i).$plit("=");
+this.asc.setCurrentModelInfo(s[0], s[1]);
+}
+});
 Clazz.defineMethod(c$, "finalizeSubclassSymmetry", 
 function(haveSymmetry){
 }, "~B");
 Clazz.defineMethod(c$, "doPreSymmetry", 
-function(){
-});
+function(doApplySymmetry){
+}, "~B");
 Clazz.defineMethod(c$, "finalizeMOData", 
 function(moData){
 this.asc.setCurrentModelInfo("moData", moData);
@@ -1288,11 +1300,10 @@ function(){
 if (this.rd() != null && this.line.indexOf("#jmolscript:") >= 0) this.checkCurrentLineForScript();
 return this.line;
 });
-Clazz.defineMethod(c$, "appendUnitCellInfo", 
+Clazz.defineMethod(c$, "addMoreUnitCellInfo", 
 function(info){
 if (this.moreUnitCellInfo == null) this.moreUnitCellInfo =  new JU.Lst();
 this.moreUnitCellInfo.addLast(info);
-this.appendLoadNote(info);
 }, "~S");
 Clazz.defineMethod(c$, "getInterface", 
 function(className){
@@ -1322,4 +1333,4 @@ function(pt, prec){
 if (this.floatifyJavaDouble) JU.PT.fixPtFloats(pt, prec);
 }, "JU.P3,~N");
 });
-;//5.0.1-v7 Thu Apr 24 22:44:18 CDT 2025
+;//5.0.1-v7 Wed Jun 11 09:30:30 CDT 2025
