@@ -105,7 +105,7 @@ if (value > this.contourPlaneMaximumValue) this.contourPlaneMaximumValue = value
 Clazz.defineMethod(c$, "createContours", 
 function(min, max, zeroOffset){
 var diff = max - min;
-this.contourValuesUsed =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nContourSegments, 0);
+this.contourValuesUsed =  Clazz.newFloatArray (this.nContourSegments, 0);
 for (var i = this.triangleCount; --i >= 0; ) this.triangles[i].check = 0;
 
 var minCutoff = -3.4028235E38;
@@ -238,4 +238,4 @@ this.contourIndex = contourIndex;
 /*eoif4*/})();
 };
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
