@@ -153,7 +153,7 @@ this.probeValues = null;
 this.sbOut = null;
 Clazz.instantialize(this, arguments);}, J.jvxl.readers, "Parameters", null);
 Clazz.prepareFields (c$, function(){
-this.anisotropy =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/3, 0);
+this.anisotropy =  Clazz.newFloatArray (3, 0);
 });
 Clazz.defineMethod(c$, "initialize", 
 function(){
@@ -546,4 +546,4 @@ function(){
 return (this.thePlane != null || this.fullyLit);
 });
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon Jun 02 10:11:19 CEST 2025
