@@ -100,7 +100,7 @@ function(out){
 }, "JU.OC");
 Clazz.defineMethod(c$, "newVoxelDataCube", 
 function(){
-this.volumeData.setVoxelDataAsArray(this.voxelData =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.nPointsX, /*org.eclipse.jdt.core.dom.SimpleName*/this.nPointsY, /*org.eclipse.jdt.core.dom.SimpleName*/this.nPointsZ, 0));
+this.volumeData.setVoxelDataAsArray(this.voxelData =  Clazz.newFloatArray (this.nPointsX, this.nPointsY, this.nPointsZ, 0));
 });
 Clazz.defineMethod(c$, "setVolumeDataV", 
 function(v){
@@ -266,8 +266,8 @@ if (this.jvxlData.vertexColors == null) return "";
 var vertexCount = this.jvxlData.vertexCount;
 var colixes = this.meshData.vcs;
 var vertexValues = this.meshData.vvs;
-if (colixes == null || colixes.length < vertexCount) this.meshData.vcs = colixes =  Clazz.newShortArray (/*org.eclipse.jdt.core.dom.SimpleName*/vertexCount, 0);
-if (vertexValues == null || vertexValues.length < vertexCount) this.meshData.vvs = vertexValues =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/vertexCount, 0);
+if (colixes == null || colixes.length < vertexCount) this.meshData.vcs = colixes =  Clazz.newShortArray (vertexCount, 0);
+if (vertexValues == null || vertexValues.length < vertexCount) this.meshData.vvs = vertexValues =  Clazz.newFloatArray (vertexCount, 0);
 for (var i = 0; i < vertexCount; i++) colixes[i] = JU.C.getColix(this.jvxlData.vertexColors[i]);
 
 return "-";
@@ -287,8 +287,8 @@ function(){
 this.yzCount = this.nPointsY * this.nPointsZ;
 if (!this.isQuiet) JU.Logger.info("reading data progressively -- yzCount = " + this.yzCount);
 this.yzPlanes = JU.AU.newFloat2(2);
-this.yzPlanes[0] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.yzCount, 0);
-this.yzPlanes[1] =  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/this.yzCount, 0);
+this.yzPlanes[0] =  Clazz.newFloatArray (this.yzCount, 0);
+this.yzPlanes[1] =  Clazz.newFloatArray (this.yzCount, 0);
 });
 Clazz.overrideMethod(c$, "getValue", 
 function(x, y, z, ptyz){
@@ -403,7 +403,7 @@ this.colorFractionBase = this.jvxlData.colorFractionBase = 35;
 this.colorFractionRange = this.jvxlData.colorFractionRange = 90;
 if (this.params.colorPhase == 0) this.params.colorPhase = 1;
 if (this.meshDataServer == null) {
-this.meshData.vcs =  Clazz.newShortArray (/*org.eclipse.jdt.core.dom.QualifiedName*/this.meshData.vc, 0);
+this.meshData.vcs =  Clazz.newShortArray (this.meshData.vc, 0);
 } else {
 this.meshDataServer.fillMeshData(this.meshData, 1, null);
 if (this.params.contactPair == null) this.meshDataServer.fillMeshData(this.meshData, 2, null);
@@ -421,7 +421,7 @@ this.jvxlData.maxColorIndex = JU.C.getColixTranslucent3(JU.C.getColix(this.param
 }this.jvxlData.isTruncated = (this.jvxlData.minColorIndex >= 0 && !this.params.isContoured);
 var useMeshDataValues = this.jvxlDataIs2dContour || this.hasColorData || this.vertexDataOnly || this.params.colorDensity || this.params.isBicolorMap && !this.params.isContoured;
 if (!useMeshDataValues) {
-if (this.haveSurfaceAtoms && this.meshData.vertexSource == null) this.meshData.vertexSource =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/this.meshData.vc, 0);
+if (this.haveSurfaceAtoms && this.meshData.vertexSource == null) this.meshData.vertexSource =  Clazz.newIntArray (this.meshData.vc, 0);
 var min = 3.4028235E38;
 var max = -3.4028235E38;
 var value;
@@ -474,10 +474,10 @@ vertexColixes[i] = this.params.colorEncoder.getColorIndex(value);
 }}
 if ((this.params.nContours > 0 || this.jvxlData.contourValues != null) && this.jvxlData.contourColixes == null) {
 var n = (this.jvxlData.contourValues == null ? this.params.nContours : this.jvxlData.contourValues.length);
-var colors = this.jvxlData.contourColixes =  Clazz.newShortArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0);
+var colors = this.jvxlData.contourColixes =  Clazz.newShortArray (n, 0);
 var values = this.jvxlData.contourValues;
 if (values == null) values = this.jvxlData.contourValuesUsed;
-if (this.jvxlData.contourValuesUsed == null) this.jvxlData.contourValuesUsed = (values == null ?  Clazz.newFloatArray (/*org.eclipse.jdt.core.dom.SimpleName*/n, 0) : values);
+if (this.jvxlData.contourValuesUsed == null) this.jvxlData.contourValuesUsed = (values == null ?  Clazz.newFloatArray (n, 0) : values);
 var dv = (valueBlue - valueRed) / (n + 1);
 this.params.colorEncoder.setRange(this.params.valueMappedToRed, this.params.valueMappedToBlue, this.params.isColorReversed);
 for (var i = 0; i < n; i++) {
@@ -646,4 +646,4 @@ return -1;
 });
 c$.colorPhases =  Clazz.newArray(-1, ["_orb", "x", "y", "z", "xy", "yz", "xz", "x2-y2", "z2"]);
 });
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
