@@ -95,7 +95,7 @@ return (s.startsWith("<![CDATA[") && s.endsWith("]]>") ? JU.PT.rep(s.substring(9
 }, "~S");
 c$.getXmlAttrib = Clazz.defineMethod(c$, "getXmlAttrib", 
 function(data, what){
-var nexta =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/1, 0);
+var nexta =  Clazz.newIntArray (1, 0);
 var pt = J.jvxl.readers.XmlReader.setNext(data, what, nexta, 1);
 if (pt < 2 || (pt = J.jvxl.readers.XmlReader.setNext(data, "\"", nexta, 0)) < 2) return "";
 var pt1 = J.jvxl.readers.XmlReader.setNext(data, "\"", nexta, -1);
@@ -129,4 +129,4 @@ if (this.line == null || this.line.indexOf("</") >= 0 && this.line.indexOf("</")
 return (this.line.indexOf("<" + name) >= 0);
 }, "~S");
 });
-;//5.0.1-v4 Tue Nov 12 14:58:21 CST 2024
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
