@@ -535,4 +535,4 @@ Clazz.superCall(this, J.navigate.Navigator, "oops", [e]);
 this.tm.navigating = false;
 }, "Exception");
 });
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Mon Jun 09 19:40:05 CEST 2025
