@@ -47,4 +47,4 @@ if (this.mar > 0) this.g3d.fillCylinderXYZ(this.colix, this.colix, 2, this.width
  else this.g3d.drawLineXYZ(xA, yA, zA, xB, yB, zB);
 }, "~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon Jun 09 21:25:18 CEST 2025
