@@ -146,4 +146,4 @@ sb.append("  axes type " + JU.PT.esc(this.axisType));
 }return sb.toString();
 }, "JU.SB");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Mon Jun 09 21:25:18 CEST 2025
