@@ -804,6 +804,8 @@ case 1094715412:
 return this.getResno();
 case 1094713366:
 return this.getAtomSite();
+case 1095241729:
+return this.getSpin();
 case 1639976963:
 return this.group.getProteinStructureType().getId();
 case 1237320707:
@@ -817,6 +819,10 @@ return this.getValence();
 }
 return 0;
 }, "~N");
+Clazz.defineMethod(c$, "getSpin", 
+function(){
+return this.group.chain.model.ms.getSpin(this.i);
+});
 Clazz.defineMethod(c$, "getSymOp", 
 function(){
 return (this.atomSymmetry == null ? 0 : this.atomSymmetry.nextSetBit(0) + 1);
@@ -1159,4 +1165,4 @@ return 0;
 });
 c$.MAD_GLOBAL = 32200;
 });
-;//5.0.1-v7 Thu Apr 10 15:57:32 CDT 2025
+;//5.0.1-v7 Wed Jun 11 15:08:00 CDT 2025
