@@ -20,4 +20,4 @@ this.axisB = JU.P3.newP(points[this.nRes]);
 JU.Measure.projectOntoAxis(this.axisB, this.axisA, this.axisUnitVector, this.vectorProjection);
 });
 });
-;//5.0.1-v7 Wed Apr 02 04:50:42 CDT 2025
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
