@@ -30,8 +30,8 @@ spg.periodicity = base.periodicity;
 }return spg;
 }, "JS.SpecialGroup,JS.Symmetry,java.util.Map,~N");
 Clazz.defineMethod(c$, "getSpecialGroup", 
-function(sym, vwr, name, type){
+function(vwr, sym, name, type){
 return this.createSpecialGroup(null, sym, JS.Symmetry.getSpecialSettingInfo(vwr, name, type), type);
-}, "JS.Symmetry,JV.Viewer,~S,~N");
+}, "JV.Viewer,JS.Symmetry,~S,~N");
 });
-;//5.0.1-v7 Thu Apr 24 22:44:18 CDT 2025
+;//5.0.1-v7 Tue Jun 10 00:39:37 CEST 2025
