@@ -1,3 +1,3 @@
 Clazz.declarePackage("JSV.api");
 Clazz.declareInterface(JSV.api, "PanelListener");
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
