@@ -19,10 +19,10 @@ this.nAdditionalMATsectors = 0;
 this.MSAT0 = null;
 Clazz.instantialize(this, arguments);}, JU, "CompoundDocHeader", null);
 Clazz.prepareFields (c$, function(){
-this.magicNumbers =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/8, 0);
-this.uniqueID16 =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/16, 0);
-this.unused =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/10, 0);
-this.MSAT0 =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/109, 0);
+this.magicNumbers =  Clazz.newByteArray (8, 0);
+this.uniqueID16 =  Clazz.newByteArray (16, 0);
+this.unused =  Clazz.newByteArray (10, 0);
+this.MSAT0 =  Clazz.newIntArray (109, 0);
 });
 Clazz.makeConstructor(c$, 
 function(compoundDocument){
@@ -65,4 +65,4 @@ throw e;
 return true;
 });
 })();
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
