@@ -17,8 +17,8 @@ this.atomList = null;
 this.atNos = null;
 Clazz.instantialize(this, arguments);}, JU, "JmolMolecule", null);
 Clazz.prepareFields (c$, function(){
-this.elementCounts =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/JU.Elements.elementNumberMax, 0);
-this.altElementCounts =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/JU.Elements.altElementMax, 0);
+this.elementCounts =  Clazz.newIntArray (JU.Elements.elementNumberMax, 0);
+this.altElementCounts =  Clazz.newIntArray (JU.Elements.altElementMax, 0);
 });
 Clazz.makeConstructor(c$, 
 function(){
@@ -89,8 +89,8 @@ function(includeMissingHydrogens, wts, isEmpirical){
 if (this.atomList == null) {
 this.atomList =  new JU.BS();
 this.atomList.setBits(0, this.atNos == null ? this.nodes.length : this.atNos.length);
-}this.elementCounts =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/JU.Elements.elementNumberMax, 0);
-this.altElementCounts =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.QualifiedName*/JU.Elements.altElementMax, 0);
+}this.elementCounts =  Clazz.newIntArray (JU.Elements.elementNumberMax, 0);
+this.altElementCounts =  Clazz.newIntArray (JU.Elements.altElementMax, 0);
 this.ac = this.atomList.cardinality();
 this.nElements = 0;
 for (var p = 0, i = this.atomList.nextSetBit(0); i >= 0; i = this.atomList.nextSetBit(i + 1), p++) {
@@ -246,4 +246,4 @@ bs.clear(i);
 }return bs;
 }, "~A,~N,JU.BS");
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Sat Jun 07 00:08:51 CEST 2025
