@@ -38,7 +38,7 @@ this.diffuseFactor = this.diffusePercent / 100;
 this.intenseFraction = this.specularPower / 100;
 this.specularFactor = this.specularPercent / 100;
 this.ashades = JU.AU.newInt2(128);
-this.sphereShadeIndexes =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.InfixExpression*/65536, 0);
+this.sphereShadeIndexes =  Clazz.newByteArray (65536, 0);
 this.sphereShapeCache = JU.AU.newInt2(128);
 });
 Clazz.makeConstructor(c$, 
@@ -109,7 +109,7 @@ if (this.ashadesGreyscale != null) this.ashadesGreyscale = JU.AU.arrayCopyII(thi
 }, "~N");
 Clazz.defineMethod(c$, "getShades2", 
 function(rgb, greyScale){
-var shades =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/64, 0);
+var shades =  Clazz.newIntArray (64, 0);
 if (rgb == 0) return shades;
 var red0 = ((rgb >> 16) & 0xFF);
 var grn0 = ((rgb >> 8) & 0xFF);
@@ -257,11 +257,11 @@ return (outside ? this.getShadeIndex(i, j, k) : this.ellipsoidShades[i + 20][j +
 }, "~N,~N,~N,~N,JU.M4");
 Clazz.defineMethod(c$, "createEllipsoidShades", 
 function(){
-this.ellipsoidShades =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/40, /*org.eclipse.jdt.core.dom.SimpleName*/40, /*org.eclipse.jdt.core.dom.SimpleName*/40, 0);
+this.ellipsoidShades =  Clazz.newByteArray (40, 40, 40, 0);
 for (var ii = 0; ii < 40; ii++) for (var jj = 0; jj < 40; jj++) for (var kk = 0; kk < 40; kk++) this.ellipsoidShades[ii][jj][kk] = this.getShadeIndex(ii - 20, jj - 20, kk);
 
 
 
 });
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
