@@ -1,3 +1,3 @@
 Clazz.declarePackage("javajs.api");
 Clazz.declareInterface(javajs.api, "GenericZipTools");
-;//5.0.1-v4 Wed Dec 11 08:23:48 CST 2024
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
