@@ -9,7 +9,7 @@ function(){
 this.putString("P6\n");
 this.putString(this.width + " " + this.height + "\n");
 this.putString("255\n");
-var ppmPixels =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.InfixExpression*/this.width * 3, 0);
+var ppmPixels =  Clazz.newByteArray (this.width * 3, 0);
 for (var pt = 0, row = 0; row < this.height; ++row) {
 for (var col = 0, j = 0; col < this.width; ++col, pt++) {
 var p = this.pixels[pt];
@@ -21,4 +21,4 @@ this.out.write(ppmPixels, 0, ppmPixels.length);
 }
 });
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Fri May 30 05:05:27 CDT 2025
