@@ -662,30 +662,30 @@ this.ll8 = null;
 Clazz.instantialize(this, arguments);}, org.apache.tools.bzip2.CBZip2InputStream, "Data", null);
 Clazz.prepareFields (c$, function(){
 this.inUse =  Clazz.newBooleanArray(256, false);
-this.seqToUnseq =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/256, 0);
-this.selector =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/18002, 0);
-this.selectorMtf =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/18002, 0);
-this.unzftab =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/256, 0);
-this.limit =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/6, /*org.eclipse.jdt.core.dom.SimpleName*/258, 0);
-this.base =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/6, /*org.eclipse.jdt.core.dom.SimpleName*/258, 0);
-this.perm =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/6, /*org.eclipse.jdt.core.dom.SimpleName*/258, 0);
-this.minLens =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/6, 0);
-this.cftab =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.NumberLiteral*/257, 0);
+this.seqToUnseq =  Clazz.newByteArray (256, 0);
+this.selector =  Clazz.newByteArray (18002, 0);
+this.selectorMtf =  Clazz.newByteArray (18002, 0);
+this.unzftab =  Clazz.newIntArray (256, 0);
+this.limit =  Clazz.newIntArray (6, 258, 0);
+this.base =  Clazz.newIntArray (6, 258, 0);
+this.perm =  Clazz.newIntArray (6, 258, 0);
+this.minLens =  Clazz.newIntArray (6, 0);
+this.cftab =  Clazz.newIntArray (257, 0);
 this.getAndMoveToFrontDecode_yy =  Clazz.newCharArray (256, '\0');
 this.temp_charArray2d =  Clazz.newCharArray (6, 258, '\0');
-this.recvDecodingTables_pos =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.SimpleName*/6, 0);
+this.recvDecodingTables_pos =  Clazz.newByteArray (6, 0);
 });
 Clazz.makeConstructor(c$, 
 function(blockSize100k){
-this.ll8 =  Clazz.newByteArray (/*org.eclipse.jdt.core.dom.InfixExpression*/blockSize100k * 100000, 0);
+this.ll8 =  Clazz.newByteArray (blockSize100k * 100000, 0);
 }, "~N");
 Clazz.defineMethod(c$, "initTT", 
 function(length){
 var ttShadow = this.tt;
 if ((ttShadow == null) || (ttShadow.length < length)) {
-this.tt = ttShadow =  Clazz.newIntArray (/*org.eclipse.jdt.core.dom.SimpleName*/length, 0);
+this.tt = ttShadow =  Clazz.newIntArray (length, 0);
 }return ttShadow;
 }, "~N");
 /*eoif3*/})();
 });
-;//5.0.1-v4 Thu Feb 20 12:29:54 CST 2025
+;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
